@@ -27,17 +27,17 @@ class UserField(forms.CharField):
             try:
                 return User.objects.get(pk=value)
             except User.DoesNotExist:
-                raise ValidationError('Unknown user_id: "%s"' % value)
+                raise ValidationError('Unknown user_id: "%s"' % value) from None
         else:
             value = value.strip()
             if value.isdigit():
                 try:
                     return User.objects.get(pk=value)
                 except User.DoesNotExist:
-                    raise ValidationError('Unknown user_id: "%s"' % value)
+                    raise ValidationError('Unknown user_id: "%s"' % value) from None
             else:
                 try:
                     return User.objects.get(
                         (Q(email=value) | Q(username=value)))
                 except User.DoesNotExist:
-                    raise ValidationError('Unknown user: "%s"' % value)
+                    raise ValidationError('Unknown user: "%s"' % value) from None
